#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_EXPONENT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_EXPONENT_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/exponent.hpp>

#endif
